@@ -452,8 +452,8 @@ static AttrEntry attr_table[] = {
     MAKE_ENTRY(NV_CTRL_GVO_SUPPORTED),
     MAKE_ENTRY(NV_CTRL_GVO_SYNC_MODE),
     MAKE_ENTRY(NV_CTRL_GVO_SYNC_SOURCE),
-    MAKE_ENTRY(NV_CTRL_GVO_OUTPUT_VIDEO_FORMAT),
-    MAKE_ENTRY(NV_CTRL_GVO_INPUT_VIDEO_FORMAT),
+    MAKE_ENTRY(NV_CTRL_GVIO_REQUESTED_VIDEO_FORMAT),
+    MAKE_ENTRY(NV_CTRL_GVIO_DETECTED_VIDEO_FORMAT),
     MAKE_ENTRY(NV_CTRL_GVO_DATA_FORMAT),
     MAKE_ENTRY(NV_CTRL_GVO_DISPLAY_X_SCREEN),
     MAKE_ENTRY(NV_CTRL_GVO_COMPOSITE_SYNC_INPUT_DETECTED),
@@ -465,9 +465,9 @@ static AttrEntry attr_table[] = {
     MAKE_ENTRY(NV_CTRL_GVO_SYNC_DELAY_LINES),
     MAKE_ENTRY(NV_CTRL_GVO_INPUT_VIDEO_FORMAT_REACQUIRE),
     MAKE_ENTRY(NV_CTRL_GVO_GLX_LOCKED),
-    MAKE_ENTRY(NV_CTRL_GVO_VIDEO_FORMAT_WIDTH),
-    MAKE_ENTRY(NV_CTRL_GVO_VIDEO_FORMAT_HEIGHT),
-    MAKE_ENTRY(NV_CTRL_GVO_VIDEO_FORMAT_REFRESH_RATE),
+    MAKE_ENTRY(NV_CTRL_GVIO_VIDEO_FORMAT_WIDTH),
+    MAKE_ENTRY(NV_CTRL_GVIO_VIDEO_FORMAT_HEIGHT),
+    MAKE_ENTRY(NV_CTRL_GVIO_VIDEO_FORMAT_REFRESH_RATE),
     MAKE_ENTRY(NV_CTRL_GVO_X_SCREEN_PAN_X),
     MAKE_ENTRY(NV_CTRL_GVO_X_SCREEN_PAN_Y),
     MAKE_ENTRY(NV_CTRL_GPU_OVERCLOCKING_STATE),
@@ -491,7 +491,7 @@ static AttrEntry attr_table[] = {
     MAKE_ENTRY(NV_CTRL_BUS_RATE),
     MAKE_ENTRY(NV_CTRL_SHOW_SLI_HUD),
     MAKE_ENTRY(NV_CTRL_XV_SYNC_TO_DISPLAY),
-    MAKE_ENTRY(NV_CTRL_GVO_OUTPUT_VIDEO_FORMAT2),
+    MAKE_ENTRY(NV_CTRL_GVIO_REQUESTED_VIDEO_FORMAT2),
     MAKE_ENTRY(NV_CTRL_GVO_OVERRIDE_HW_CSC),
     MAKE_ENTRY(NV_CTRL_GVO_CAPABILITIES),
     MAKE_ENTRY(NV_CTRL_GVO_COMPOSITE_TERMINATION),
